couchdb.tools.replication_helper.ReplicationHelper

Package couchdb :: Package tools :: Module replication_helper :: Class ReplicationHelper |

# Class ReplicationHelper

    object --+
             |
            ReplicationHelper

Listener daemon for CouchDB database notifications

Instance Methods
__init__(self, source, targets, options) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
concat_uri(self, server, path) Concat a server name and a path, is smart about slashes |
trigger_creation(self, database) Creates database in all target servers. |
trigger_deletion(self, database) Deletes database in all target servers. |
trigger_replication(self, database) Triggers replication between source and target servers. |
sync_databases(self) Sync self.databases to all target servers. |
__call__(self) Reads notifications from stdin and triggers replication |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, source, targets, options) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)